#[non_exhaustive]pub enum CallbackState {
Pending,
Enqueued,
FinishedOk,
}Available on crate feature
ent only.Expand description
State of a callback job of a Batch.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Pending
Not enqueued yet.
Enqueued
Enqueued by the server, because the jobs belonging to this batch have finished executing.
If a callback has been consumed, it’s status is still Enqueued.
If a callback has finished with failure, it’s status remains Enqueued.
FinishedOk
The enqueued callback job has been consumed and successfully executed.